@@ -1,4 +1,4 @@
-recurse <- function(fy,tpm,ispd,nc)
+recurse <- function(fy,tpm,ispd,lns)
 {
 #
 # Function recurse to revise the ``recursive probabilities'',
@@ -11,8 +11,8 @@ K2 <- K*K
 L  <- ncol(fy)
 M  <- K*L
 N  <- K*M - K2
-n  <- L/nc
-epsilon <- 10*.Machine$double.eps
+nreps <- length(lns)
+epsilon <- sqrt(.Machine$double.eps)
 
 # Recursive probabilities:
 
@@ -21,9 +21,9 @@ epsilon <- 10*.Machine$double.eps
 		fy=as.double(fy),
                 xispd=as.double(ispd),
                 tpm=as.double(tpm),
-		nc=as.integer(nc),
+		nreps=as.integer(nreps),
                 epsilon=as.double(epsilon),
-		n=as.integer(n),
+		lns=as.integer(lns),
                 nstate=as.integer(K),
                 wrk=double(K2),
 		xlc=double(L),
